@@ -32,11 +32,8 @@ import getpass
 import logging
 import textwrap
 import warnings
-import requests
 import re
 
-from distutils.version import LooseVersion
-
 import six
 
 from fedora.client import OpenIdBaseClient, FedoraClientError, BaseClient
